@@ -1,6 +1,5 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+  Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
   like most MySQL Connectors. There are special exceptions to the
@@ -69,12 +68,12 @@ public class CallableStatement extends PreparedStatement implements
 				JDBC_4_CSTMT_2_ARGS_CTOR = Class.forName(
 						"com.mysql.jdbc.JDBC4CallableStatement")
 						.getConstructor(
-								new Class[] { ConnectionImpl.class,
+								new Class[] { MySQLConnection.class,
 										CallableStatementParamInfo.class });
 				JDBC_4_CSTMT_4_ARGS_CTOR = Class.forName(
 						"com.mysql.jdbc.JDBC4CallableStatement")
 						.getConstructor(
-								new Class[] { ConnectionImpl.class,
+								new Class[] { MySQLConnection.class,
 										String.class, String.class,
 										Boolean.TYPE });
 			} catch (SecurityException e) {
@@ -494,7 +493,7 @@ public class CallableStatement extends PreparedStatement implements
 	 * @throws SQLException
 	 *             if an error occurs
 	 */
-	public CallableStatement(ConnectionImpl conn,
+	public CallableStatement(MySQLConnection conn,
 			CallableStatementParamInfo paramInfo) throws SQLException {
 		super(conn, paramInfo.nativeSql, paramInfo.catalogInUse);
 
@@ -515,7 +514,7 @@ public class CallableStatement extends PreparedStatement implements
 	 * classes that are present in JDBC4 method signatures.
 	 */
 
-	protected static CallableStatement getInstance(ConnectionImpl conn, String sql,
+	protected static CallableStatement getInstance(MySQLConnection conn, String sql,
 			String catalog, boolean isFunctionCall) throws SQLException {
 		if (!Util.isJdbc4()) {
 			return new CallableStatement(conn, sql, catalog, isFunctionCall);
@@ -533,7 +532,7 @@ public class CallableStatement extends PreparedStatement implements
 	 * classes that are present in JDBC4 method signatures.
 	 */
 
-	protected static CallableStatement getInstance(ConnectionImpl conn,
+	protected static CallableStatement getInstance(MySQLConnection conn,
 			CallableStatementParamInfo paramInfo) throws SQLException {
 		if (!Util.isJdbc4()) {
 			return new CallableStatement(conn, paramInfo);
@@ -614,7 +613,7 @@ public class CallableStatement extends PreparedStatement implements
 	 * @throws SQLException
 	 *             if an error occurs
 	 */
-	public CallableStatement(ConnectionImpl conn, String sql, String catalog,
+	public CallableStatement(MySQLConnection conn, String sql, String catalog,
 			boolean isFunctionCall) throws SQLException {
 		super(conn, sql, catalog);
 
@@ -2202,12 +2201,25 @@ public class CallableStatement extends PreparedStatement implements
 				if (!this.callingStoredFunction && outParamInfo.isOut) {
 					String outParameterName = mangleParameterName(outParamInfo.paramName);
 
-					int outParamIndex;
+					int outParamIndex = 0;
 					
 					if (this.placeholderToParameterIndexMap == null) { 
 							outParamIndex = outParamInfo.index + 1;
 					} else {
-							outParamIndex = this.placeholderToParameterIndexMap[outParamInfo.index - 1 /* JDBC is 1-based */];
+							// Find it, todo: remove this linear search
+							boolean found = false;
+							
+							for (int i = 0; i < this.placeholderToParameterIndexMap.length; i++) {
+								if (this.placeholderToParameterIndexMap[i] == outParamInfo.index) {
+									outParamIndex = i + 1; /* JDBC is 1-based */
+									found = true;
+									break;
+								}
+							}
+							
+							if (!found) {
+								throw SQLError.createSQLException("boo!", "S1000", this.connection.getExceptionInterceptor());
+							}
 					}
 					
 					this.setBytesNoEscapeNoQuotes(outParamIndex,
@@ -2388,7 +2400,7 @@ public class CallableStatement extends PreparedStatement implements
 			}
 
 			ResultSet rs = null;
-			PreparedStatement ps = null;
+			java.sql.PreparedStatement ps = null;
 			
 			try {
 				String procName = extractProcedureName();
@@ -2406,12 +2418,13 @@ public class CallableStatement extends PreparedStatement implements
 					procName = new String(StringUtils.stripEnclosure(procName
 							.getBytes(), "`", "`"));
 				}
-				ps = ((DatabaseMetaData) this.connection
-						.getMetaData())
-						.prepareMetaDataSafeStatement("SELECT SQL_DATA_ACCESS FROM "
+				ps = this.connection
+						.prepareStatement("SELECT SQL_DATA_ACCESS FROM "
 								+ " information_schema.routines "
 								+ " WHERE routine_schema = ? "
 								+ " AND routine_name = ?");
+				ps.setMaxRows(0);
+				ps.setFetchSize(0);
 
 				ps.setString(1, catalog);
 				ps.setString(2, procName);
