@@ -1,6 +1,5 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+  Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
   like most MySQL Connectors. There are special exceptions to the
@@ -21,7 +20,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
   02110-1301 USA
-
+ 
  */
 
 package com.mysql.jdbc;
@@ -1636,4 +1635,37 @@ public interface ConnectionProperties {
 	public abstract boolean getQueryTimeoutKillsConnection();
 
 	public abstract void setQueryTimeoutKillsConnection(boolean queryTimeoutKillsConnection);
+   
+   public int getMaxAllowedPacket();
+
+   boolean getRetainStatementAfterResultSetClose();
+   
+	public abstract int getLoadBalancePingTimeout();
+
+	public abstract void setLoadBalancePingTimeout(int loadBalancePingTimeout);
+
+	public abstract boolean getLoadBalanceValidateConnectionOnSwapServer();
+	
+	public abstract void setLoadBalanceValidateConnectionOnSwapServer(boolean loadBalanceValidateConnectionOnSwapServer);
+	
+	public abstract String getLoadBalanceConnectionGroup();
+
+	public abstract void setLoadBalanceConnectionGroup(String loadBalanceConnectionGroup);
+
+	public abstract String getLoadBalanceExceptionChecker();
+
+	public abstract void setLoadBalanceExceptionChecker(String loadBalanceExceptionChecker);
+
+	public abstract String getLoadBalanceSQLStateFailover();
+
+	public abstract void setLoadBalanceSQLStateFailover(String loadBalanceSQLStateFailover);
+
+	public abstract String getLoadBalanceSQLExceptionSubclassFailover();
+
+	public abstract void setLoadBalanceSQLExceptionSubclassFailover(String loadBalanceSQLExceptionSubclassFailover);
+
+	public abstract boolean getLoadBalanceEnableJMX();
+
+	public abstract void setLoadBalanceEnableJMX(boolean loadBalanceEnableJMX);	
+	
 }
