@@ -1,5 +1,5 @@
 /*
- Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
+ Copyright  2002-2004 MySQL AB, 2008-2010 Sun Microsystems
  All rights reserved. Use is subject to license terms.
 
  This program is free software; you can redistribute it and/or modify
@@ -54,7 +54,7 @@ public class Field {
 
 	private String collationName = null;
 
-	private ConnectionImpl connection = null;
+	private MySQLConnection connection = null;
 
 	private String databaseName = null;
 
@@ -117,7 +117,7 @@ public class Field {
 	/**
 	 * Constructor used when communicating with 4.1 and newer servers
 	 */
-	Field(ConnectionImpl conn, byte[] buffer, int databaseNameStart,
+	Field(MySQLConnection conn, byte[] buffer, int databaseNameStart,
 			int databaseNameLength, int tableNameStart, int tableNameLength,
 			int originalTableNameStart, int originalTableNameLength,
 			int nameStart, int nameLength, int originalColumnNameStart,
@@ -354,7 +354,7 @@ public class Field {
 	/**
 	 * Constructor used when communicating with pre 4.1 servers
 	 */
-	Field(ConnectionImpl conn, byte[] buffer, int nameStart, int nameLength,
+	Field(MySQLConnection conn, byte[] buffer, int nameStart, int nameLength,
 			int tableNameStart, int tableNameLength, int length, int mysqlType,
 			short colFlag, int colDecimals) throws SQLException {
 		this(conn, buffer, -1, -1, tableNameStart, tableNameLength, -1, -1,
@@ -956,7 +956,7 @@ public class Field {
 	 * @param conn
 	 *            DOCUMENT ME!
 	 */
-	public void setConnection(ConnectionImpl conn) {
+	public void setConnection(MySQLConnection conn) {
 		this.connection = conn;
 
 		if (this.charsetName == null || this.charsetIndex == 0) {
