@@ -1,5 +1,5 @@
 /*
- Copyright  2007 MySQL AB, 2008 Sun Microsystems
+ Copyright  2007 MySQL AB, 2008-2010 Sun Microsystems
  All rights reserved. Use is subject to license terms.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
@@ -45,29 +45,32 @@ public class RandomBalanceStrategy implements BalanceStrategy {
 		// we don't have anything to initialize
 	}
 
-	public Connection pickConnection(LoadBalancingConnectionProxy proxy,
-			List configuredHosts, Map liveConnections, long[] responseTimes,
+	public ConnectionImpl pickConnection(LoadBalancingConnectionProxy proxy,
+			List<String> configuredHosts, Map<String, ConnectionImpl> liveConnections, long[] responseTimes,
 			int numRetries) throws SQLException {
 		int numHosts = configuredHosts.size();
 
 		SQLException ex = null;
 
-		List whiteList = new ArrayList(numHosts);
+		List<String> whiteList = new ArrayList<String>(numHosts);
 		whiteList.addAll(configuredHosts);
 		
-		Map blackList = proxy.getGlobalBlacklist();
+		Map<String, Long> blackList = proxy.getGlobalBlacklist();
 
 		whiteList.removeAll(blackList.keySet());
 		
-		Map whiteListMap = this.getArrayIndexMap(whiteList);
+		Map<String, Integer> whiteListMap = this.getArrayIndexMap(whiteList);
 		
 
 		for (int attempts = 0; attempts < numRetries;) {
 			int random = (int) Math.floor((Math.random() * whiteList.size()));
+			if(whiteList.size() == 0){
+				throw SQLError.createSQLException("No hosts configured", null);
+			}
 
-			String hostPortSpec = (String) whiteList.get(random);
+			String hostPortSpec = whiteList.get(random);
 
-			Connection conn = (Connection) liveConnections.get(hostPortSpec);
+			ConnectionImpl conn = liveConnections.get(hostPortSpec);
 
 			if (conn == null) {
 				try {
@@ -75,11 +78,9 @@ public class RandomBalanceStrategy implements BalanceStrategy {
 				} catch (SQLException sqlEx) {
 					ex = sqlEx;
 
-					if (sqlEx instanceof CommunicationsException
-							|| "08S01".equals(sqlEx.getSQLState())) {
+					if (proxy.shouldExceptionTriggerFailover(sqlEx)) {
 
-						Integer whiteListIndex = (Integer) whiteListMap
-								.get(hostPortSpec);
+						Integer whiteListIndex = whiteListMap.get(hostPortSpec);
 
 						// exclude this host from being picked again
 						if (whiteListIndex != null) {
@@ -96,7 +97,7 @@ public class RandomBalanceStrategy implements BalanceStrategy {
 							}
 
 							// start fresh
-							whiteListMap = new HashMap(numHosts);
+							whiteListMap = new HashMap<String, Integer>(numHosts);
 							whiteList.addAll(configuredHosts);
 							blackList = proxy.getGlobalBlacklist();
 
@@ -110,7 +111,7 @@ public class RandomBalanceStrategy implements BalanceStrategy {
 					}
 				}
 			}
-
+			
 			return conn;
 		}
 
@@ -121,8 +122,8 @@ public class RandomBalanceStrategy implements BalanceStrategy {
 		return null; // we won't get here, compiler can't tell
 	}
 	
-	private Map getArrayIndexMap(List l) {
-		Map m = new HashMap(l.size());
+	private Map<String, Integer> getArrayIndexMap(List<String> l) {
+		Map<String, Integer> m = new HashMap<String, Integer>(l.size());
 		for (int i = 0; i < l.size(); i++) {
 			m.put(l.get(i), new Integer(i));
 		}
