@@ -1,5 +1,5 @@
 /*
- Copyright  2004-2007 MySQL AB, 2008-2009 Sun Microsystems
+ Copyright  2004-2007 MySQL AB, 2008-2010 Sun Microsystems
  All rights reserved. Use is subject to license terms.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
@@ -324,7 +324,7 @@ public class ReplicationConnection implements Connection, PingTarget {
 	 */
 	public PreparedStatement prepareStatement(String sql) throws SQLException {
 		PreparedStatement pstmt = this.currentConnection.prepareStatement(sql);
-
+		
 		((com.mysql.jdbc.Statement) pstmt).setPingTarget(this);
 		
 		return pstmt;
@@ -2394,6 +2394,22 @@ public class ReplicationConnection implements Connection, PingTarget {
 	public void setLoadBalanceBlacklistTimeout(int loadBalanceBlacklistTimeout) {
 		this.currentConnection.setLoadBalanceBlacklistTimeout(loadBalanceBlacklistTimeout);
 	}
+	
+	public int getLoadBalancePingTimeout() {
+		return this.currentConnection.getLoadBalancePingTimeout();
+	}
+
+	public void setLoadBalancePingTimeout(int loadBalancePingTimeout) {
+		this.currentConnection.setLoadBalancePingTimeout(loadBalancePingTimeout);
+	}
+	
+	public boolean getLoadBalanceValidateConnectionOnSwapServer() {
+		return this.currentConnection.getLoadBalanceValidateConnectionOnSwapServer();
+	}
+
+	public void setLoadBalanceValidateConnectionOnSwapServer(boolean loadBalanceValidateConnectionOnSwapServer) {
+		this.currentConnection.setLoadBalanceValidateConnectionOnSwapServer(loadBalanceValidateConnectionOnSwapServer);
+	}
 
 	public int getRetriesAllDown() {
 		return this.currentConnection.getRetriesAllDown();
@@ -2436,4 +2452,78 @@ public class ReplicationConnection implements Connection, PingTarget {
 		
 		return props;
 	}
+
+   public String getHost() {
+      return currentConnection.getHost();
+   }
+
+   public void setProxy(MySQLConnection proxy) {
+      currentConnection.setProxy(proxy);
+   }
+
+ 	public boolean getRetainStatementAfterResultSetClose() {
+		return currentConnection.getRetainStatementAfterResultSetClose();
+	}
+
+ 	public int getMaxAllowedPacket() {
+		return currentConnection.getMaxAllowedPacket();
+	}
+ 	
+	public String getLoadBalanceConnectionGroup() {
+		return currentConnection.getLoadBalanceConnectionGroup();
+	}
+
+	public boolean getLoadBalanceEnableJMX() {
+		return currentConnection.getLoadBalanceEnableJMX();
+	}
+
+	public String getLoadBalanceExceptionChecker() {
+		return currentConnection
+				.getLoadBalanceExceptionChecker();
+	}
+
+	public String getLoadBalanceSQLExceptionSubclassFailover() {
+		return currentConnection
+				.getLoadBalanceSQLExceptionSubclassFailover();
+	}
+
+	public String getLoadBalanceSQLStateFailover() {
+		return currentConnection
+				.getLoadBalanceSQLStateFailover();
+	}
+
+	public void setLoadBalanceConnectionGroup(String loadBalanceConnectionGroup) {
+		currentConnection
+				.setLoadBalanceConnectionGroup(loadBalanceConnectionGroup);
+		
+	}
+
+	public void setLoadBalanceEnableJMX(boolean loadBalanceEnableJMX) {
+		currentConnection
+				.setLoadBalanceEnableJMX(loadBalanceEnableJMX);
+		
+	}
+
+	public void setLoadBalanceExceptionChecker(
+			String loadBalanceExceptionChecker) {
+		currentConnection
+				.setLoadBalanceExceptionChecker(loadBalanceExceptionChecker);
+		
+	}
+
+	public void setLoadBalanceSQLExceptionSubclassFailover(
+			String loadBalanceSQLExceptionSubclassFailover) {
+		currentConnection
+				.setLoadBalanceSQLExceptionSubclassFailover(loadBalanceSQLExceptionSubclassFailover);
+		
+	}
+
+	public void setLoadBalanceSQLStateFailover(
+			String loadBalanceSQLStateFailover) {
+		currentConnection
+				.setLoadBalanceSQLStateFailover(loadBalanceSQLStateFailover);
+		
+	}
+	
+
 }
