@@ -1,5 +1,5 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
+ Copyright  2002-2007 MySQL AB, 2008-2010 Sun Microsystems
  All rights reserved. Use is subject to license terms.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
@@ -33,7 +33,6 @@ import java.sql.Statement;
 
 import com.mysql.jdbc.profiler.ProfilerEvent;
 import com.mysql.jdbc.profiler.ProfilerEventHandler;
-import com.mysql.jdbc.profiler.ProfilerEventHandlerFactory;
 
 /**
  * Allows streaming of MySQL data.
@@ -158,7 +157,7 @@ public class RowDataDynamic implements RowData {
 
 		Object mutex = this;
 
-		ConnectionImpl conn = null;
+		MySQLConnection conn = null;
 
 		if (this.owner != null) {
 			conn = this.owner.connection;
