@@ -1,5 +1,5 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008-2009 Sun Microsystems
+ Copyright  2002-2007 MySQL AB, 2008-2010 Sun Microsystems
  All rights reserved. Use is subject to license terms.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
@@ -38,6 +38,7 @@ import java.util.TimeZone;
 import com.mysql.jdbc.Connection;
 import com.mysql.jdbc.ExceptionInterceptor;
 import com.mysql.jdbc.Extension;
+import com.mysql.jdbc.MySQLConnection;
 import com.mysql.jdbc.MysqlErrorNumbers;
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.Util;
@@ -2594,6 +2595,22 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public void setLoadBalanceBlacklistTimeout(int loadBalanceBlacklistTimeout) {
 		this.mc.setLoadBalanceBlacklistTimeout(loadBalanceBlacklistTimeout);
 	}
+	public int getLoadBalancePingTimeout() {
+		return this.mc.getLoadBalancePingTimeout();
+	}
+
+	public void setLoadBalancePingTimeout(int loadBalancePingTimeout) {
+		this.mc.setLoadBalancePingTimeout(loadBalancePingTimeout);
+	}
+	
+	public boolean getLoadBalanceValidateConnectionOnSwapServer() {
+		return this.mc.getLoadBalanceValidateConnectionOnSwapServer();
+	}
+
+	public void setLoadBalanceValidateConnectionOnSwapServer(
+			boolean loadBalanceValidateConnectionOnSwapServer) {
+		this.mc.setLoadBalanceValidateConnectionOnSwapServer(loadBalanceValidateConnectionOnSwapServer);
+	}
 	
 	public void setRetriesAllDown(int retriesAllDown) {
 		this.mc.setRetriesAllDown(retriesAllDown);
@@ -2631,4 +2648,78 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public Properties getProperties() {
 		return this.mc.getProperties();
 	}
+
+   public String getHost() {
+      return this.mc.getHost();
+   }
+
+   public void setProxy(MySQLConnection conn) {
+      this.mc.setProxy(conn);
+   }
+
+ 	public boolean getRetainStatementAfterResultSetClose() {
+		return this.mc.getRetainStatementAfterResultSetClose();
+	}
+
+   public int getMaxAllowedPacket() {
+		return this.mc.getMaxAllowedPacket();
+	}
+   
+	public String getLoadBalanceConnectionGroup() {
+		return this.mc.getLoadBalanceConnectionGroup();
+	}
+
+	public boolean getLoadBalanceEnableJMX() {
+		return this.mc.getLoadBalanceEnableJMX();
+	}
+
+	public String getLoadBalanceExceptionChecker() {
+		return this.mc
+				.getLoadBalanceExceptionChecker();
+	}
+
+	public String getLoadBalanceSQLExceptionSubclassFailover() {
+		return this.mc
+				.getLoadBalanceSQLExceptionSubclassFailover();
+	}
+
+	public String getLoadBalanceSQLStateFailover() {
+		return this.mc
+				.getLoadBalanceSQLStateFailover();
+	}
+
+	public void setLoadBalanceConnectionGroup(String loadBalanceConnectionGroup) {
+		this.mc
+				.setLoadBalanceConnectionGroup(loadBalanceConnectionGroup);
+		
+	}
+
+	public void setLoadBalanceEnableJMX(boolean loadBalanceEnableJMX) {
+		this.mc
+				.setLoadBalanceEnableJMX(loadBalanceEnableJMX);
+		
+	}
+
+	public void setLoadBalanceExceptionChecker(
+			String loadBalanceExceptionChecker) {
+		this.mc
+				.setLoadBalanceExceptionChecker(loadBalanceExceptionChecker);
+		
+	}
+
+	public void setLoadBalanceSQLExceptionSubclassFailover(
+			String loadBalanceSQLExceptionSubclassFailover) {
+		this.mc
+				.setLoadBalanceSQLExceptionSubclassFailover(loadBalanceSQLExceptionSubclassFailover);
+		
+	}
+
+	public void setLoadBalanceSQLStateFailover(
+			String loadBalanceSQLStateFailover) {
+		this.mc
+				.setLoadBalanceSQLStateFailover(loadBalanceSQLStateFailover);
+		
+	}
+
+
 }
\ No newline at end of file
