@@ -1,6 +1,5 @@
 /*
- Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+  Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPL,
   like most MySQL Connectors. There are special exceptions to the
@@ -21,9 +20,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
   02110-1301 USA
-
-
-
+ 
  */
 package testsuite.regression;
 
@@ -41,15 +38,16 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
-import java.util.Collection;
 import java.util.Enumeration;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 import java.util.StringTokenizer;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -63,10 +61,12 @@ import testsuite.UnreliableSocketFactory;
 
 import com.mysql.jdbc.ConnectionImpl;
 import com.mysql.jdbc.Driver;
+import com.mysql.jdbc.LoadBalancingConnectionProxy;
 import com.mysql.jdbc.Messages;
+import com.mysql.jdbc.MySQLConnection;
 import com.mysql.jdbc.MysqlDataTruncation;
-import com.mysql.jdbc.MysqlErrorNumbers;
 import com.mysql.jdbc.NonRegisteringDriver;
+import com.mysql.jdbc.RandomBalanceStrategy;
 import com.mysql.jdbc.ReplicationConnection;
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.StandardSocketFactory;
@@ -609,7 +609,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			String originalConnectionId = getSingleIndexedValueWithQuery(
 					failoverConnection, 1, "SELECT CONNECTION_ID()").toString();
 			
-			for (int i = 0; i < 49; i++) {
+			for (int i = 0; i < 50; i++) {
 				failoverConnection.createStatement().executeQuery("SELECT 1");
 			}
 
@@ -1235,7 +1235,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 
 			try {
 				replConn = getMasterSlaveReplicationConnection();
-				assertTrue(!((ConnectionImpl) ((ReplicationConnection) replConn)
+				assertTrue(!((MySQLConnection) ((ReplicationConnection) replConn)
 						.getMasterConnection()).hasSameProperties(
 								((ReplicationConnection) replConn)
 										.getSlavesConnection()));
@@ -1910,7 +1910,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			accessorName.append(propertyName.substring(1));
 			
 			try {
-				clazz.getMethod(accessorName.toString(), null);
+				clazz.getMethod(accessorName.toString(), (Class[])null);
 			} catch (NoSuchMethodException nsme) {
 				missingGettersBuf.append(accessorName.toString());
 				missingGettersBuf.append("\n");
@@ -2323,7 +2323,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 				adminStmt.executeUpdate("flush privileges");
 				
 				try {
-					((ConnectionImpl)adminConn).changeUser(user, unicodePassword);
+					((MySQLConnection)adminConn).changeUser(user, unicodePassword);
 				} catch (SQLException sqle) {
 					assertTrue("Connection with non-latin1 password failed", false);
 				}
@@ -2463,7 +2463,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	public void testBug44587() throws Exception {
 		Exception e = null;
 		String msg = SQLError.createLinkFailureMessageBasedOnHeuristics(
-				(ConnectionImpl) this.conn, 
+				(MySQLConnection) this.conn,
 				System.currentTimeMillis() - 1000,
 				System.currentTimeMillis() - 2000,
 				e, 
@@ -2478,7 +2478,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	public void testBug45419() throws Exception {
 		Exception e = null;
 		String msg = SQLError.createLinkFailureMessageBasedOnHeuristics(
-				(ConnectionImpl) this.conn, 
+				(MySQLConnection) this.conn,
 				System.currentTimeMillis() - 1000,
 				System.currentTimeMillis() - 2000,
 				e, 
@@ -2635,7 +2635,9 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	}
 	
 	public void testBug48486() throws Exception {
-		int endHost = dbUrl.lastIndexOf("/");
+		int beginHost = dbUrl.indexOf("//");
+		
+		int endHost = dbUrl.indexOf("/", beginHost + 2);
 		String databaseStuff = dbUrl.substring(endHost + 1);
 		
 		Properties props = new NonRegisteringDriver().parseURL(dbUrl, null);
@@ -2686,4 +2688,151 @@ public class ConnectionRegressionTest extends BaseTestCase {
 		((com.mysql.jdbc.Connection)c).resetServerState();
 		assertEquals("bar", getSingleIndexedValueWithQuery(c, 1, "SELECT @foo"));
 	}
-}
+	
+	public void testBug51266() throws Exception {
+		Properties props = new Properties();
+		props.setProperty("roundRobinLoadBalance", "true"); // shouldn't be needed, but used in reported bug, it's removed by the driver
+		Set downedHosts = new HashSet();
+		downedHosts.add("first");
+		
+		// this loop will hang on the first unreliable host if the bug isn't fixed.
+		for (int i = 0; i < 20; i++) {
+			getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props, downedHosts).close();
+		}
+	}
+	
+	// Tests fix for Bug#51643 - connection chosen by load balancer "sticks" to statements
+	// that live past commit()/rollback().
+	
+	public void testBug51643() throws Exception {
+		Properties props = new Properties();
+		props.setProperty("loadBalanceStrategy", "com.mysql.jdbc.SequentialBalanceStrategy");
+		
+		Connection lbConn = getUnreliableLoadBalancedConnection(new String[] { "first", "second"}, props);
+		try {
+			PreparedStatement cPstmt = lbConn.prepareStatement("SELECT connection_id()");
+			PreparedStatement serverPstmt = lbConn.prepareStatement("SELECT connection_id()");
+			Statement plainStmt = lbConn.createStatement();
+			
+			lbConn.setAutoCommit(false);
+			this.rs = cPstmt.executeQuery();
+			this.rs.next();
+			String cPstmtConnId = this.rs.getString(1);
+			
+			this.rs = serverPstmt.executeQuery();
+			this.rs.next();
+			String serverPstmtConnId = this.rs.getString(1);
+			
+			this.rs = plainStmt.executeQuery("SELECT connection_id()");
+			this.rs.next();
+			String plainStmtConnId = this.rs.getString(1);
+			lbConn.commit();
+			lbConn.setAutoCommit(false);
+			
+			this.rs = cPstmt.executeQuery();
+			this.rs.next();
+			String cPstmtConnId2 = this.rs.getString(1);
+			assertFalse(cPstmtConnId2.equals(cPstmtConnId));
+			
+			this.rs = serverPstmt.executeQuery();
+			this.rs.next();
+			String serverPstmtConnId2 = this.rs.getString(1);
+			assertFalse(serverPstmtConnId2.equals(serverPstmtConnId));
+			
+			this.rs = plainStmt.executeQuery("SELECT connection_id()");
+			this.rs.next();
+			String plainStmtConnId2 = this.rs.getString(1);
+			assertFalse(plainStmtConnId2.equals(plainStmtConnId));
+		} finally {
+			lbConn.close();
+		}
+	}
+	
+	public void testBug51783() throws Exception {
+		Properties props = new Properties();
+		props.setProperty("loadBalanceStrategy", ForcedLoadBalanceStrategy.class.getName());
+		props.setProperty("loadBalanceBlacklistTimeout", "5000");
+		props.setProperty("loadBalancePingTimeout", "100");
+		props.setProperty("loadBalanceValidateConnectionOnSwapServer", "true");
+		
+		String portNumber = new NonRegisteringDriver().parseURL(dbUrl, null).getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY);
+		
+		if (portNumber == null) {
+			portNumber = "3306";
+		}
+		
+		ForcedLoadBalanceStrategy.forceFutureServer("first:" + portNumber, -1);
+		Connection conn2 = this.getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props);
+		conn2.setAutoCommit(false);
+		conn2.createStatement().execute("SELECT 1");
+		ForcedLoadBalanceStrategy.forceFutureServer("second:" + portNumber, -1);
+		UnreliableSocketFactory.downHost("second");
+		try{
+			conn2.commit();  // will be on second after this
+			assertTrue("Connection should be closed", conn2.isClosed());
+		} catch (SQLException e){
+			fail("Should not error because failure to get another server.");
+		}
+		conn2.close();
+		
+		props = new Properties();
+		props.setProperty("loadBalanceStrategy", ForcedLoadBalanceStrategy.class.getName());
+		props.setProperty("loadBalanceBlacklistTimeout", "5000");
+		props.setProperty("loadBalancePingTimeout", "100");
+		props.setProperty("loadBalanceValidateConnectionOnSwapServer", "false");
+		ForcedLoadBalanceStrategy.forceFutureServer("first:" + portNumber, -1);
+		conn2 = this.getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props);
+		conn2.setAutoCommit(false);
+		conn2.createStatement().execute("SELECT 1");
+		ForcedLoadBalanceStrategy.forceFutureServer("second:" + portNumber, 1);
+		UnreliableSocketFactory.downHost("second");
+		try{
+			conn2.commit();  // will be on second after this
+			assertFalse("Connection should not be closed, should be able to connect to first", conn2.isClosed());
+		} catch (SQLException e){
+			fail("Should not error because failure to get another server.");
+		}
+	}
+	
+	public static class ForcedLoadBalanceStrategy extends RandomBalanceStrategy {
+		
+		private static String forcedFutureServer = null;
+		private static int forceFutureServerTimes = 0;
+		public static void forceFutureServer(String host, int times){
+			forcedFutureServer = host;
+			forceFutureServerTimes = times;
+		}
+
+		public com.mysql.jdbc.ConnectionImpl pickConnection(
+				LoadBalancingConnectionProxy proxy, List configuredHosts,
+				Map liveConnections, long[] responseTimes, int numRetries)
+				throws SQLException {
+			if(forcedFutureServer == null || forceFutureServerTimes == 0){
+				return super.pickConnection(proxy, configuredHosts, liveConnections, responseTimes, numRetries);
+			}
+			if(forceFutureServerTimes > 0){
+				forceFutureServerTimes--;
+			}
+			ConnectionImpl conn = (ConnectionImpl) liveConnections.get(forcedFutureServer);
+
+			if (conn == null) {
+				conn = proxy.createConnectionForHost(forcedFutureServer);
+				
+			}
+			return conn;
+		}
+
+		public void destroy() {
+			super.destroy();
+			
+		}
+
+		public void init(com.mysql.jdbc.Connection conn, Properties props)
+				throws SQLException {
+			super.init(conn, props);
+			
+		}
+		
+	}
+	
+}
\ No newline at end of file
